@@ -57,6 +57,7 @@ check <- function(object, object.name, check.name, check.func, na.ok=FALSE)
 #         }
 #     }
 # }
+
 # mostly for checking user arguments (so error wording is for that)
 # but also occasionally used for other sanity checking
 
@@ -308,6 +309,8 @@ fix.lim <- function(lim)
 
 gen.colnames <- function(x, prefix="x", alt.prefix=prefix, trace=0, xname=NULL)
 {
+    if(NCOL(x) == 0)
+        return(NULL)
     # If prefix is long and has characters like ( or [ then use the
     # alternate prefix.  This is sometimes necessary when prefix is
     # generated using deparse and the arg is something like
